pub trait ClosedNeg: Sized + Neg<Output = Self> { }Expand description
Trait alias for Neg with result of type Self.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
pub trait ClosedNeg: Sized + Neg<Output = Self> { }Trait alias for Neg with result of type Self.
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".